@@ -163,9 +163,16 @@ class ImagestoreTest(TestCase):
 
     def test_album_order(self):
         self.album.delete()
-        Album.objects.create(name='b2', order=1, user=self.user)
-        Album.objects.create(name='a1', order=2, user=self.user)
+        a1 = Album.objects.create(name='b2', order=1, user=self.user)
+        a2 = Album.objects.create(name='a1', order=2, user=self.user)
         response = self.client.get(reverse('imagestore:index'))
         self.assertEqual(response.status_code, 200)
         self.assertEqual(response.context['object_list'][0].name, 'b2')
-        self.assertEqual(response.context['object_list'][1].name, 'a1')
\ No newline at end of file
+        self.assertEqual(response.context['object_list'][1].name, 'a1')
+        a1.order, a2.order = 2, 1
+        a1.save()
+        a2.save()
+        response = self.client.get(reverse('imagestore:index'))
+        self.assertEqual(response.status_code, 200)
+        self.assertEqual(response.context['object_list'][0].name, 'a1')
+        self.assertEqual(response.context['object_list'][1].name, 'b2')
\ No newline at end of file
